Database Migration — Pootle 2.9.0b4 documentation

# Database Migration

Note

Please note that the database migration must be performed before upgrading Pootle.

Using dumpdata and loaddata commands to migrate between databases is no longer supported.

The MySQL MyISAM backend is no longer supported. Use InnoDB instead.

There are several tools available to migrate between databases. We recommend having a look through this list for the following supported backends:

- PostgreSQL
- SQLite
- MySQL/MariaDB (InnoDB)